﻿using System;
using System.Drawing;
using System.Drawing.Imaging;
using System.Windows.Forms;
using J4L.Vision;
using J4L.Vision.Util;
using J4L.Vision.QRCode;


public class QRCodeSample
{

    private string[] testSet={ "qrcode10bw90.png", "qrcode7bw2.png","foto0072.png" ,"qrcode.png","qrcode2.png","qrcode3.png","qrcode6.png"};
    //private string[] testSet = { "qrcode2.png" };

    private string dir = "qrimages\\";


    [STAThread]
    public static void Main(string[] args)
    {
        J4L.Vision.Util.SystemProperties.registerAppArgs(args);
        QRCodeSample sample = new QRCodeSample();
        try
        {


            sample.runTests();
        }
        catch (Exception e)
        {

            Console.WriteLine(e.Message);
            Console.WriteLine(e.StackTrace);
        }

    }
    /**
         * read all test files
         *
         */
    public void runTests()
    {
        // these are the default values
        SystemProperties.setProperty("minArea", "10");
        SystemProperties.setProperty("maxArea", "900000");
        //SystemProperties.setDebug(true);

        for (int i = 0; i < testSet.GetLength(0); i++)
        {
            try
            {

                Console.WriteLine("");
                Console.WriteLine("---  ---------------------------");
                Console.WriteLine("Scanning File: " + testSet[i]);
                Console.WriteLine("");
                scanImage(testSet[i]);
                Console.WriteLine("------------------------------");
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);
                Console.WriteLine(e.StackTrace);
            }
        }
    }

    /**
     * scan file
     * @param file image file

     * @throws Exception
     */
    public void scanImage(string file)
    {

        Bitmap im = (Bitmap)loadImage(dir + file);

        QRCodeReader reader = new QRCodeReader();

        Console.WriteLine("Start " + DateTime.Now);
        RImage rim = new RImage(im);

        QRCodeData[] barcodes = reader.read(rim);
        rim = null;
        im = null;
        Console.WriteLine("End " + DateTime.Now);
        if (barcodes.GetLength(0) == 0) Console.WriteLine("*** NO BARCODE FOUND ***");

        for (int i = 0; i < barcodes.GetLength(0); i++)
        {
            Console.WriteLine("Barcode  found " + barcodes[i].toString());

        }

    }

    /**
     * load image from file
     */
    public Image loadImage(String f)
    {

        Image bp = Bitmap.FromFile(f);
        Bitmap b2 = new Bitmap(bp.Width, bp.Height, PixelFormat.Format24bppRgb);
        Graphics g = Graphics.FromImage(b2);
        g.DrawImage(bp, 0, 0, bp.Width, bp.Height);
        g.Dispose();
        return b2;

    }
}

